<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Lausekkeen virhe</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark theme</source>
        <translation>Tumma teema</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Yksinkertainen tila</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Tieteellinen tila</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Deepinin Laskin</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>Deepinin Laskin on yksinkertainen ja helppokäyttöinen työpöytälaskin. Ohjelma tukee yhteenlaskua, vähennyslaskua, kertolaskua ja jakolaskua.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Lausekkeen virhe</translation>
    </message>
</context>
</TS>